from utime import sleep_ms
from machine import Pin

traffic_lights = [
    [ # Traffic light 1
        Pin(28, Pin.OUT),  #Red
        Pin(27, Pin.OUT),  #Amber
        Pin(26, Pin.OUT)], #Green
    [ # Traffic light 2
        Pin(22, Pin.OUT),
        Pin(21, Pin.OUT),
        Pin(20, Pin.OUT)],
    [ # Traffic light 3
        Pin(18, Pin.OUT),
        Pin(17, Pin.OUT),
        Pin(16, Pin.OUT)]
    ]

# Time in green state (ms)
on_time = 4000
# Time in transition states (ms)
transition_time = 1000 

# During startup set all to Red - known state
for this_light in traffic_lights :
    this_light[0].value(1) # Set red on
    this_light[1].value(0) # Set amber off
    this_light[2].value(0) # Set green off
    
# track which light is on (or in transition) - all other lights are in stop state
active_light = 0

    
def set_ready (traffic_light):
    traffic_light[0].value(1)
    traffic_light[1].value(1)
    traffic_light[2].value(0)
    
def set_go (traffic_light):
    traffic_light[0].value(0)
    traffic_light[1].value(0)
    traffic_light[2].value(1)
    
def set_warn (traffic_light):
    traffic_light[0].value(0)
    traffic_light[1].value(1)
    traffic_light[2].value(0)
    
def set_stop (traffic_light):
    traffic_light[0].value(1)
    traffic_light[1].value(0)
    traffic_light[2].value(0)

# Each interation through loop covers active state of one traffic light
while (1):
    active_light += 1
    if active_light >= len(traffic_lights):
        active_light = 0
    # Start sequence
    set_ready (traffic_lights[active_light])
    sleep_ms(transition_time)
    set_go (traffic_lights[active_light])
    sleep_ms(on_time)
    set_warn (traffic_lights[active_light])
    sleep_ms(transition_time)
    set_stop (traffic_lights[active_light])
    sleep_ms(transition_time)
    
    
    

